@@ -1,5 +1,4 @@
 from isd.errors import IsdError
-from isd.io import open
 from isd.record import Record
 
-__all__ = ["Record", "IsdError", "open"]
+__all__ = ["IsdError", "Record"]
